@@ -1,4 +1,4 @@
-# Copyright (c) 2023 Apex Resource Management Solution Ltd. (ApexRMS). All rights reserved.
+# Copyright (c) 2024 Apex Resource Management Solution Ltd. (ApexRMS). All rights reserved.
 # MIT License
 #' @include AAAClassDefinitions.R
 NULL
@@ -84,12 +84,16 @@ setMethod("package", signature(ssimObject = "Session"), function(ssimObject, ins
       } else if (grepl("The remote name could not be resolved", tt[1])) {
         out <- "Could not connect to the package server."
       } else {
-        out <- .dataframeFromSSim(tt, colNames = c("name", "description", "version"), csv = FALSE)
+        out <- .dataframeFromSSim(tt, localNames = TRUE, csv=FALSE)
       }
+      drops <- c("x")
+      out <- out[ , !(names(out) %in% drops)]
       return(out)
     } else {
       tt <- command(c("list", arg, "csv"), ssimObject)
       out <- .dataframeFromSSim(tt, localNames = TRUE, csv = FALSE)
+      drops <- c("x")
+      out <- out[ , !(names(out) %in% drops)]
       return(out)
     }
   } else {
@@ -99,7 +103,7 @@ setMethod("package", signature(ssimObject = "Session"), function(ssimObject, ins
       pkgList <- command(c("installed"), ssimObject,
                          program = "SyncroSim.PackageManager.exe")
       pkgDf <- .dataframeFromSSim(pkgList,
-                                  colNames = c("name", "description", "version"),
+                                  localNames = TRUE,
                                   csv = FALSE)
       if (listTemplates %in% pkgDf$name == FALSE) {
         stop("SyncroSim package not installed")
@@ -112,6 +116,8 @@ setMethod("package", signature(ssimObject = "Session"), function(ssimObject, ins
       out <- .dataframeFromSSim(tt,
                                 colNames =c("name", "displayName", "installed"),
                                 csv = F)
+      drops <- c("x")
+      out <- out[ , !(names(out) %in% drops)]
       return(out)
     } else {
       stop("listTemplates must be a character name of a SyncroSim Package")
