@@ -1,4 +1,4 @@
-# Copyright (c) 2023 Apex Resource Management Solution Ltd. (ApexRMS). All rights reserved.
+# Copyright (c) 2024 Apex Resource Management Solution Ltd. (ApexRMS). All rights reserved.
 # MIT License
 #' @include AAAClassDefinitions.R
 NULL
@@ -135,13 +135,6 @@ setMethod(
         if (grepl(cStatus[1], "Creating Library from Template")) {
           stop("Problem creating library: ", cStatus[1])
         }
-        
-        # Print out available scenarios for the template
-        args <- list(list = NULL, scenarios = NULL, lib = path, csv = NULL)
-        tt <- command(args, session)
-        tempScenarios <- read.csv(text = tt)
-        message(paste(c("Scenarios available in this template:",
-                      tempScenarios$Name), collapse = "    "))
       } 
       
       if (!is.null(template) & !is.character(template)) {
@@ -293,17 +286,17 @@ setMethod(".ssimLibrary", signature(name = "SsimObject"), function(name, package
 #' @details  
 #' Example arguments:
 #' \itemize{
-#'   \item {If name is SyncroSim Project or Scenario: }{Returns the 
-#'          \code{\link{SsimLibrary}} associated with the Project or Scenario.}
-#'   \item {If name is \code{NULL}: }{Create/open a SsimLibrary in the current working 
-#'          directory with the filename SsimLibrary.ssim.}
-#'   \item {If name is a string: }{If string is not a valid path treat as filename 
+#'   \item If name is SyncroSim Project or Scenario: Returns the 
+#'          \code{\link{SsimLibrary}} associated with the Project or Scenario.
+#'   \item If name is \code{NULL}: Create/open a SsimLibrary in the current working 
+#'          directory with the filename SsimLibrary.ssim.
+#'   \item If name is a string: If string is not a valid path treat as filename 
 #'          in working directory. If no file suffix provided in string then add 
 #'          .ssim. Attempts to open a SsimLibrary of that name. If SsimLibrary does not 
-#'          exist creates a SsimLibrary of type package in the current working directory.}
-#'   \item {If given a name and a package: }{Create/open a SsimLibrary called [name].ssim. 
+#'          exist creates a SsimLibrary of type package in the current working directory.
+#'   \item If given a name and a package: Create/open a SsimLibrary called [name].ssim. 
 #'          Returns an error if the SsimLibrary already exists but is a different type 
-#'          of package.}
+#'          of package.
 #' }
 #' 
 #' @examples
